@@ -427,7 +427,7 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 	 * updated (e.g. the no-spell-check context class).
 	 */
 	buffer_signals[HIGHLIGHT_UPDATED] =
-	    g_signal_new_class_handler ("highlight-updated",
+	    g_signal_new_class_handler ("highlight_updated",
 	                                G_OBJECT_CLASS_TYPE (object_class),
 	                                G_SIGNAL_RUN_LAST,
 	                                G_CALLBACK (gtk_source_buffer_real_highlight_updated),
@@ -442,11 +442,11 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 	 * @buffer: the buffer that received the signal
 	 * @mark: the #GtkSourceMark
 	 *
-	 * The ::source-mark-updated signal is emitted each time
+	 * The ::source_mark_updated signal is emitted each time
 	 * a mark is added to, moved or removed from the @buffer.
 	 */
 	buffer_signals[SOURCE_MARK_UPDATED] =
-	    g_signal_new ("source-mark-updated",
+	    g_signal_new ("source_mark_updated",
 			   G_OBJECT_CLASS_TYPE (object_class),
 			   G_SIGNAL_RUN_LAST,
 			   0,
