@@ -20,6 +20,12 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "gtksourcecompletionproposal.h"
+
 /**
  * SECTION:completionproposal
  * @title: GtkSourceCompletionProposal
@@ -40,8 +46,6 @@
  * will be used.
  */
 
-#include "gtksourcecompletionproposal.h"
-
 /* Signals */
 enum
 {
