@@ -93,10 +93,6 @@ struct _GtkSourceGutterPrivate
 
 G_DEFINE_TYPE_WITH_PRIVATE (GtkSourceGutter, gtk_source_gutter, G_TYPE_OBJECT)
 
-static gboolean on_view_draw (GtkSourceView   *view,
-                              cairo_t         *cr,
-                              GtkSourceGutter *gutter);
-
 static gboolean on_view_motion_notify_event (GtkSourceView   *view,
                                              GdkEventMotion  *event,
                                              GtkSourceGutter *gutter);
@@ -293,12 +289,6 @@ set_view (GtkSourceGutter *gutter,
 {
 	gutter->priv->view = view;
 
-	g_signal_connect_object (view,
-				 "draw",
-				 G_CALLBACK (on_view_draw),
-				 gutter,
-				 G_CONNECT_AFTER);
-
 	g_signal_connect_object (view,
 				 "motion-notify-event",
 				 G_CALLBACK (on_view_motion_notify_event),
@@ -1102,7 +1092,18 @@ draw_cells (GtkSourceGutter *gutter,
 
 		if (!gtk_text_iter_ends_line (&end))
 		{
-			gtk_text_iter_forward_to_line_end (&end);
+			/*
+			 * It turns out that gtk_text_iter_forward_to_line_end
+			 * is slower than jumping to the next line in the
+			 * btree index and then moving backwards a character.
+			 * We don't really care that we might be after the
+			 * newline breaking characters, since those are part
+			 * of the same line (rather than the next line).
+			 */
+			if (gtk_text_iter_forward_line (&end))
+			{
+				gtk_text_iter_backward_char (&end);
+			}
 		}
 
 		/* Possible improvement: if buffer and window coords have the
@@ -1220,10 +1221,10 @@ end_draw (GtkSourceGutter *gutter)
 	}
 }
 
-static gboolean
-on_view_draw (GtkSourceView   *view,
-              cairo_t         *cr,
-              GtkSourceGutter *gutter)
+void
+gtk_source_gutter_draw (GtkSourceGutter *gutter,
+                        GtkSourceView   *view,
+                        cairo_t         *cr)
 {
 	GdkRectangle clip;
 	GtkTextView *text_view;
@@ -1237,7 +1238,7 @@ on_view_draw (GtkSourceView   *view,
 
 	if (!get_clip_rectangle (gutter, view, cr, &clip))
 	{
-		return GDK_EVENT_PROPAGATE;
+		return;
 	}
 
 	gutter->priv->is_drawing = TRUE;
@@ -1294,8 +1295,6 @@ on_view_draw (GtkSourceView   *view,
 
 	g_array_free (renderer_widths, TRUE);
 	lines_info_free (info);
-
-	return GDK_EVENT_PROPAGATE;
 }
 
 static Renderer *
