@@ -102,9 +102,23 @@ struct _GtkSourceGutterRendererClass
 
 	void (*end)                 (GtkSourceGutterRenderer      *renderer);
 
+	/**
+	 * GtkSourceGutterRendererClass::change_view:
+	 * @renderer: a #GtkSourceGutterRenderer.
+	 * @old_view: (allow-none): the old #GtkTextView.
+	 *
+	 * This is called when the text view changes for @renderer.
+	 */
 	void (*change_view)         (GtkSourceGutterRenderer      *renderer,
 	                             GtkTextView                  *old_view);
 
+	/**
+	 * GtkSourceGutterRendererClass::change_buffer:
+	 * @renderer: a #GtkSourceGutterRenderer.
+	 * @old_buffer: (allow-none): the old #GtkTextBuffer.
+	 *
+	 * This is called when the text buffer changes for @renderer.
+	 */
 	void (*change_buffer)       (GtkSourceGutterRenderer      *renderer,
 	                             GtkTextBuffer                *old_buffer);
 
@@ -134,8 +148,10 @@ struct _GtkSourceGutterRendererClass
 	                             GtkSourceGutterRendererState  state);
 };
 
-GType gtk_source_gutter_renderer_get_type (void) G_GNUC_CONST;
+GTK_SOURCE_AVAILABLE_IN_ALL
+GType    gtk_source_gutter_renderer_get_type (void) G_GNUC_CONST;
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void     gtk_source_gutter_renderer_begin           (GtkSourceGutterRenderer      *renderer,
                                                      cairo_t                      *cr,
                                                      GdkRectangle                 *background_area,
@@ -143,6 +159,7 @@ void     gtk_source_gutter_renderer_begin           (GtkSourceGutterRenderer
                                                      GtkTextIter                  *start,
                                                      GtkTextIter                  *end);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void     gtk_source_gutter_renderer_draw            (GtkSourceGutterRenderer      *renderer,
                                                      cairo_t                      *cr,
                                                      GdkRectangle                 *background_area,
@@ -151,66 +168,86 @@ void     gtk_source_gutter_renderer_draw            (GtkSourceGutterRenderer
                                                      GtkTextIter                  *end,
                                                      GtkSourceGutterRendererState  state);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void     gtk_source_gutter_renderer_end             (GtkSourceGutterRenderer      *renderer);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 gint     gtk_source_gutter_renderer_get_size        (GtkSourceGutterRenderer      *renderer);
+
+GTK_SOURCE_AVAILABLE_IN_ALL
 void    gtk_source_gutter_renderer_set_size         (GtkSourceGutterRenderer      *renderer,
                                                      gint                          size);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void     gtk_source_gutter_renderer_set_visible     (GtkSourceGutterRenderer      *renderer,
                                                      gboolean                      visible);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 gboolean gtk_source_gutter_renderer_get_visible     (GtkSourceGutterRenderer      *renderer);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void     gtk_source_gutter_renderer_get_padding     (GtkSourceGutterRenderer      *renderer,
                                                      gint                         *xpad,
                                                      gint                         *ypad);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void     gtk_source_gutter_renderer_set_padding     (GtkSourceGutterRenderer      *renderer,
                                                      gint                          xpad,
                                                      gint                          ypad);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void     gtk_source_gutter_renderer_get_alignment   (GtkSourceGutterRenderer      *renderer,
                                                      gfloat                       *xalign,
                                                      gfloat                       *yalign);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void     gtk_source_gutter_renderer_set_alignment   (GtkSourceGutterRenderer      *renderer,
                                                      gfloat                        xalign,
                                                      gfloat                        yalign);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void     gtk_source_gutter_renderer_set_alignment_mode (GtkSourceGutterRenderer              *renderer,
                                                         GtkSourceGutterRendererAlignmentMode  mode);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 GtkTextWindowType
 	gtk_source_gutter_renderer_get_window_type  (GtkSourceGutterRenderer      *renderer);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 GtkTextView *gtk_source_gutter_renderer_get_view    (GtkSourceGutterRenderer      *renderer);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 GtkSourceGutterRendererAlignmentMode
 	gtk_source_gutter_renderer_get_alignment_mode (GtkSourceGutterRenderer    *renderer);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 gboolean gtk_source_gutter_renderer_get_background  (GtkSourceGutterRenderer      *renderer,
                                                      GdkRGBA                      *color);
 
+GTK_SOURCE_AVAILABLE_IN_ALL
 void     gtk_source_gutter_renderer_set_background  (GtkSourceGutterRenderer      *renderer,
                                                      const GdkRGBA                *color);
 
 /* Emits the 'activate' signal */
+GTK_SOURCE_AVAILABLE_IN_ALL
 void     gtk_source_gutter_renderer_activate        (GtkSourceGutterRenderer      *renderer,
                                                      GtkTextIter                  *iter,
                                                      GdkRectangle                 *area,
                                                      GdkEvent                     *event);
 
 /* Emits the 'query-activatable' signal */
+GTK_SOURCE_AVAILABLE_IN_ALL
 gboolean gtk_source_gutter_renderer_query_activatable (GtkSourceGutterRenderer      *renderer,
                                                        GtkTextIter                  *iter,
                                                        GdkRectangle                 *area,
                                                        GdkEvent                     *event);
 
 /* Emits the 'queue-draw' signal */
+GTK_SOURCE_AVAILABLE_IN_ALL
 void     gtk_source_gutter_renderer_queue_draw      (GtkSourceGutterRenderer      *renderer);
 
 /* Emits the 'query-tooltip' signal */
+GTK_SOURCE_AVAILABLE_IN_ALL
 gboolean gtk_source_gutter_renderer_query_tooltip   (GtkSourceGutterRenderer      *renderer,
                                                      GtkTextIter                  *iter,
                                                      GdkRectangle                 *area,
@@ -219,6 +256,7 @@ gboolean gtk_source_gutter_renderer_query_tooltip   (GtkSourceGutterRenderer
                                                      GtkTooltip                   *tooltip);
 
 /* Emits the 'query-data' signal */
+GTK_SOURCE_AVAILABLE_IN_ALL
 void     gtk_source_gutter_renderer_query_data      (GtkSourceGutterRenderer      *renderer,
                                                      GtkTextIter                  *start,
                                                      GtkTextIter                  *end,
