@@ -146,19 +146,18 @@ gtk_source_language_manager_class_init (GtkSourceLanguageManagerClass *klass)
 	g_object_class_install_property (object_class,
 					 PROP_SEARCH_PATH,
 					 g_param_spec_boxed ("search-path",
-						 	     _("Language specification directories"),
-							     _("List of directories where the "
-							       "language specification files (.lang) "
-							       "are located"),
+						 	     "Language specification directories",
+							     "List of directories where the "
+							     "language specification files (.lang) "
+							     "are located",
 							     G_TYPE_STRV,
 							     G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class,
 					 PROP_LANGUAGE_IDS,
 					 g_param_spec_boxed ("language-ids",
-						 	     _("Language ids"),
-							     _("List of the ids of the available "
-							       "languages"),
+						 	     "Language ids",
+							     "List of the ids of the available languages",
 							     G_TYPE_STRV,
 							     G_PARAM_READABLE));
 }
@@ -405,11 +404,11 @@ ensure_languages (GtkSourceLanguageManager *lm)
  *
  * Returns the ids of the available languages.
  *
- * Returns: (nullable) (transfer none): a %NULL-terminated array of
- * string containing the ids of the available languages or %NULL if no
- * language is available.  The array is sorted alphabetically
- * according to the language name.  The array is owned by @lm and must
- * not be modified.
+ * Returns: (nullable) (array zero-terminated=1) (transfer none):
+ * a %NULL-terminated array of strings containing the ids of the available
+ * languages or %NULL if no language is available.
+ * The array is sorted alphabetically according to the language name.
+ * The array is owned by @lm and must not be modified.
  */
 const gchar * const *
 gtk_source_language_manager_get_language_ids (GtkSourceLanguageManager *lm)
