@@ -21,6 +21,10 @@
  * Author: Sébastien Wilmet
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "gtksourcetag.h"
 
 /**
@@ -172,6 +176,7 @@ gtk_source_tag_init (GtkSourceTag *tag)
  * use.
  *
  * Returns: a new #GtkSourceTag.
+ * Since: 3.20
  */
 GtkTextTag *
 gtk_source_tag_new (const gchar *name)
