@@ -26,6 +26,8 @@
 
 G_BEGIN_DECLS
 
+typedef struct _GtkSourceBufferInputStream	GtkSourceBufferInputStream;
+typedef struct _GtkSourceBufferOutputStream	GtkSourceBufferOutputStream;
 typedef struct _GtkSourceCompletionContainer	GtkSourceCompletionContainer;
 typedef struct _GtkSourceCompletionModel	GtkSourceCompletionModel;
 typedef struct _GtkSourceContextEngine		GtkSourceContextEngine;
@@ -37,6 +39,13 @@ typedef struct _GtkSourcePixbufHelper		GtkSourcePixbufHelper;
 typedef struct _GtkSourceRegex			GtkSourceRegex;
 typedef struct _GtkSourceUndoManagerDefault	GtkSourceUndoManagerDefault;
 
+#ifdef _MSC_VER
+/* For Visual Studio, we need to export the symbols used by the unit tests */
+#define GTK_SOURCE_INTERNAL __declspec(dllexport)
+#else
+#define GTK_SOURCE_INTERNAL G_GNUC_INTERNAL
+#endif
+
 G_END_DECLS
 
 #endif /* __GTK_SOURCE_TYPES_PRIVATE_H__ */
